==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/ts/Edit_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translation>Nastavitve aplikacije</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translation>Nastavitve risbe</translation>
    </message>
    <message>
        <location line="+312"/>
        <source>Restart required</source>
        <translation>Potreben je ponovni zagon</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translation>QCAD je potrebno ponovno zagnat,
da bodo spremembe začele delovat.</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translation>Referenčna točka</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation>Orodja urejanja</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation>Prikaži orodja urejanja</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translation>&amp;Uredi</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+85"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location line="-88"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Clear Search</source>
        <translation>Počisti iskanje</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Expand Tree</source>
        <translation>Razširi drevo</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translation>Združi drevo</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translation>Obnovi na privzete vrednosti</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/ts/Edit_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translation>Nastavitve aplikacije</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translation>Nastavitve risbe</translation>
    </message>
    <message>
        <location line="+300"/>
        <source>Apply preferences</source>
        <translation>Uveljavi nastavitve</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Restart required</source>
        <translation>Potreben je ponovni zagon</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translation>QCAD je potrebno ponovno zagnat,
da bodo spremembe začele delovat.</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Defaults for </source>
        <translation>Privzeto za </translation>
    </message>
    <message>
        <location line="+2"/>
        <source>These are default preferences for new drawings.</source>
        <translation>To so privzete nastavitve za nove risbe.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Preferences of the current drawing can be changed under&lt;br/&gt;&lt;i&gt;Edit &amp;gt; Drawing Preferences&lt;/i&gt;.</source>
        <translation>Nastavitve trenutne risbe se lahko spremenijo pod &lt;br/&gt;&lt;i&gt;Uredi &amp;gt; Nastavitve risbe&lt;/i&gt;.</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Changes will affect new drawings but NOT the current drawing.</source>
        <translation>Spremembe bodo vplivale na nove risbe in NE na trenutno risbo.</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translation>Referenčna točka</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation>Orodja urejanja</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation>Prikaži orodja urejanja</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translation>&amp;Uredi</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+71"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location line="-74"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Clear Search</source>
        <translation type="vanished">Počisti iskanje</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Expand Tree</source>
        <translation>Razširi drevo</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translation>Združi drevo</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translation>Obnovi na privzete vrednosti</translation>
    </message>
</context>
</TS>
